diff mbox series

[committed] sort.cc: fix mentions of sorting networks in comments

Message ID 20231126163858.9328-1-amonakov@ispras.ru
State New
Headers show
Series [committed] sort.cc: fix mentions of sorting networks in comments | expand

Commit Message

Alexander Monakov Nov. 26, 2023, 4:38 p.m. UTC
Avoid using 'network sort' (a misnomer) in sort.cc, the correct term is
'sorting networks'.

gcc/ChangeLog:

	* sort.cc: Use 'sorting networks' in comments.
---
 gcc/sort.cc | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
diff mbox series

Patch

diff --git a/gcc/sort.cc b/gcc/sort.cc
index 9a0113fb62f..feef345830c 100644
--- a/gcc/sort.cc
+++ b/gcc/sort.cc
@@ -25,7 +25,7 @@  along with GCC; see the file COPYING3.  If not see
    - deterministic (but not necessarily stable)
    - fast, especially for common cases (0-5 elements of size 8 or 4)
 
-   The implementation uses a network sort for up to 5 elements and
+   The implementation uses sorting networks for up to 5 elements and
    a merge sort on top of that.  Neither stage has branches depending on
    comparator result, trading extra arithmetic for branch mispredictions.  */
 
@@ -53,7 +53,7 @@  struct sort_ctx
   char   *out; // output buffer
   size_t n;    // number of elements
   size_t size; // element size
-  size_t nlim; // limit for network sort
+  size_t nlim; // limit for using sorting networks
 };
 
 /* Like sort_ctx, but for use with qsort_r-style comparators.  Several
@@ -151,7 +151,7 @@  cmp1 (char *e0, char *e1, sort_ctx *c)
   return x & (c->cmp (e0, e1) >> 31);
 }
 
 /* Execute network sort on 2 to 5 elements from IN, placing them into C->OUT.
    IN may be equal to C->OUT, in which case elements are sorted in place.  */
 template<typename sort_ctx>
 static void
@@ -151,7 +151,7 @@  cmp1 (char *e0, char *e1, sort_ctx *c)
 }
 
-/* Execute network sort on 2 to 5 elements from IN, placing them into C->OUT.
+/* Apply a sorting network to 2 to 5 elements from IN, placing them into C->OUT.
    IN may be equal to C->OUT, in which case elements are sorted in place.  */
 template<typename sort_ctx>